----------------------------------------------------------------------------------------------------------------------------------------------
----------------------------------------------------------------------------------------------------------------------------------------------
-- File:        MapOptions.lua
-- Description: Custom MapOptions file that makes possible to set up variable options before game starts, like ModOptions.lua
-- Author:      SirArtturi, Lurker, Smoth, jK
----------------------------------------------------------------------------------------------------------------------------------------------
----------------------------------------------------------------------------------------------------------------------------------------------
--	NOTES:
--	- using an enumerated table lets you specify the options order
--
--	These keywords must be lowercase for LuaParser to read them.
--
--	key:			the string used in the script.txt
--	name:		 the displayed name
--	desc:		 the description (could be used as a tooltip)
--	type:		 the option type
--	def:			the default value
--	min:			minimum value for number options
--	max:			maximum value for number options
--	step:		 quantization step, aligned to the def value
--	maxlen:	 the maximum string length for string options
--	items:		array of item strings for list options
--	scope:		'all', 'player', 'team', 'allyteam'			<<< not supported yet >>>
--
--------------------------------------------------------------------------------
--------------------------------------------------------------------------------

local options = {
--// Sections
	{
		key  = 'Economy',
		name = 'Economy Settings',
		desc = '',
		type = 'section',
	},

	{
		key  = 'Features',
		name = 'Feature Settings',
		desc = '',
		type = 'section',
	},

--// Options
	--// Economy
	{
		key   = 'wind',
		name  = 'Wind Speed',
		desc  = 'How strong the wind will blow',
		type  = 'list',
		section = 'Economy',
		def   = 'normal',
		items = {
			{ key = 'low', name = "Low", desc = "Wind speed 1-15" },
			{ key = 'normal', name = "Normal", desc = "Wind speed 1-25" },
			{ key = 'high', name = "High", desc = "Wind speed 15-25" },
		},
	},

	{
		key  = 'tidal',
		name = 'Tidal Strength',
		desc = 'Tidal energy levels - How much energy is produced via tidal generators',
		type = 'list',
		section = 'Economy',
		def  = 'normal',
		items = {
			{ key = 'low', name = "Low", desc = "Tidal strength 20" },
			{ key = 'normal', name = "Normal", desc = "Tidal strength 25" },
			{ key = 'high', name = "High", desc = "Tidal strength 30" },
		},
	},
	
	{
		key     = 'extractorradius',
		name    = 'Extractor Radius',
		desc    = 'Sets the metal extractor radius',
		type    = 'number',
		section = 'Economy',
		def     = 75,
		min     = 1,
		max     = 10000,
		step    = 1,
	},
	
	--// Features
	{
		key     = 'beherith',
		name    = 'Behemoth Option',
		desc    = 'Enable the Behemoth Artifacts (resurrectable, appear on the four middle platforms)',
		type    = 'bool',
		section = 'Features',
		def     = false,
	},
	
	{
		key     = 'bluestone',
		name    = 'Millenium Option',
		desc    = 'Enable the Millenium Artifact (resurrectable, appears on the central platform)',
		type    = 'bool',
		section = 'Features',
		def     = false,
	},
}

return options